@@ -70,14 +70,14 @@ SCR::SCR( QString type, QString id )
     Simulator::self()->addToUpdateList( this );
 
     addPropGroup( { tr("Main"), {
-new DoubProp<SCR>("GateRes", tr("Gate Resistance"),"Ω"
-                 , this, &SCR::gateRes, &SCR::setGateRes ),
+        new DoubProp<SCR>("GateRes", tr("Gate Resistance"), "Ω"
+                         , this, &SCR::gateRes, &SCR::setGateRes ),
 
-new DoubProp<SCR>("TrigCurr", tr("Trigger Current"),"A"
-                 , this, &SCR::trigCurr, &SCR::setTrigCurr ),
+        new DoubProp<SCR>("TrigCurr", tr("Trigger Current"), "mA"
+                         , this, &SCR::trigCurr, &SCR::setTrigCurr ),
 
-new DoubProp<SCR>("HoldCurr", tr("Holding Current"),"A"
-                 , this, &SCR::holdCurr, &SCR::setHoldCurr )
+        new DoubProp<SCR>("HoldCurr", tr("Holding Current"), "mA"
+                         , this, &SCR::holdCurr, &SCR::setHoldCurr )
     },0 } );
 }
 SCR::~SCR()
@@ -146,9 +146,9 @@ void SCR::voltChanged()
     }
 }
 
-void SCR::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget )
+void SCR::paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w )
 {
-    Component::paint( p, option, widget );
+    Component::paint( p, o, w );
 
     p->setBrush( Qt::black );
 
