@@ -44,25 +44,25 @@ LedBar::LedBar( QString type, QString id )
     setValLabelPos(-16,-44-12, 0);
 
     addPropGroup( { tr("Main"), {
-        new StrProp <LedBar>("Color", tr("Color"),"" , this
-                        , &LedBar::colorStr, &LedBar::setColorStr,0,"enum" ),
+        new StrProp<LedBar>("Color", tr("Color"), ""
+                           , this, &LedBar::colorStr, &LedBar::setColorStr,0,"enum" ),
 
-        new IntProp <LedBar>("Size" , tr("Size"),"_Leds", this
-                    , &LedBar::size, &LedBar::setSize, propNoCopy ),
+        new IntProp<LedBar>("Size" , tr("Size"), "_Leds"
+                           , this, &LedBar::size, &LedBar::setSize, propNoCopy ),
 
-        new BoolProp<LedBar>("Grounded", tr("Grounded"),"" , this
-                    , &LedBar::grounded, &LedBar::setGrounded, propNoCopy ),
+        new BoolProp<LedBar>("Grounded", tr("Grounded"), ""
+                            , this, &LedBar::grounded, &LedBar::setGrounded, propNoCopy ),
     }, 0} );
 
     addPropGroup( { tr("Electric"), {
-        new DoubProp<LedBar>("Threshold" , tr("Forward Voltage"),"V", this
-                        , &LedBar::threshold,  &LedBar::setThreshold ),
+        new DoubProp<LedBar>("Threshold" , tr("Forward Voltage"), "V"
+                            , this, &LedBar::threshold,  &LedBar::setThreshold ),
 
-        new DoubProp<LedBar>("MaxCurrent", tr("Max Current")    ,"A", this
-                        , &LedBar::maxCurrent, &LedBar::setMaxCurrent ),
+        new DoubProp<LedBar>("MaxCurrent", tr("Max Current"),"mA"
+                            , this, &LedBar::maxCurrent, &LedBar::setMaxCurrent ),
 
-        new DoubProp<LedBar>("Resistance", tr("Resistance")     ,"Ω", this
-                        , &LedBar::res,        &LedBar::setRes ),
+        new DoubProp<LedBar>("Resistance", tr("Resistance"),"Ω"
+                            , this, &LedBar::res,        &LedBar::setRes ),
     }, 0} );
 }
 LedBar::~LedBar(){}
@@ -195,4 +195,6 @@ void LedBar::paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w )
 
     Component::paint( p, o, w );
     p->drawRoundRect( m_area, 4, 4 );
+
+    Component::paintSelected( p );
 }
