@@ -85,9 +85,14 @@ Stepper::Stepper( QString type, QString id )
     Simulator::self()->addToUpdateList( this );
 
     addPropGroup( { tr("Main"), {
-new BoolProp<Stepper>( "Bipolar"   , tr("Bipolar")           ,"" , this, &Stepper::bipolar, &Stepper::setBipolar ),
-new IntProp <Stepper>( "Steps"     , tr("Steps per Rotation"),"" , this, &Stepper::steps,   &Stepper::setSteps ),
-new DoubProp<Stepper>( "Resistance", tr("Resistance")        ,"Ω", this, &Stepper::res,     &Stepper::setRes )
+        new BoolProp<Stepper>( "Bipolar", tr("Bipolar"), ""
+                             , this, &Stepper::bipolar, &Stepper::setBipolar ),
+
+        new IntProp <Stepper>("Steps", tr("Steps per Rotation"), ""
+                             , this, &Stepper::steps, &Stepper::setSteps ),
+
+        new DoubProp<Stepper>( "Resistance", tr("Resistance"),"Ω"
+                             , this, &Stepper::res, &Stepper::setRes )
     },0} );
 }
 Stepper::~Stepper(){}
