@@ -10,7 +10,7 @@
 
 class LibraryItem;
 
-class MAINMODULE_EXPORT Capacitor : public CapacitorBase
+class Capacitor : public CapacitorBase
 {
     public:
         Capacitor( QString type, QString id );
@@ -19,7 +19,7 @@ class MAINMODULE_EXPORT Capacitor : public CapacitorBase
  static Component* construct( QString type, QString id );
  static LibraryItem* libraryItem();
 
-        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget ) override;
+        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w ) override;
 };
 
 #endif
