@@ -18,21 +18,23 @@
 #include "doubleprop.h"
 #include "propdialog.h"
 
-Component *Strain::construct (QObject* parent, QString type, QString id)
-{ return new Strain (parent, type, id); }
+#define tr(str) simulideTr("Strain",str)
+
+Component *Strain::construct( QString type, QString id)
+{ return new Strain ( type, id); }
 
 LibraryItem* Strain::libraryItem()
 {
     return new LibraryItem(
-        tr( "Force Strain Gauge" ),
+        tr("Force Strain Gauge"),
         "Resistive Sensors",
         "strain.png",
         "Strain",
         Strain::construct );
 }
 
-Strain::Strain( QObject* parent, QString type, QString id )
-      : VarResBase( parent, type, id )
+Strain::Strain( QString type, QString id )
+      : VarResBase( type, id )
 {
     m_areaComp = QRectF(-12,-20, 24, 24 );
     m_area     = m_areaComp;
@@ -40,14 +42,24 @@ Strain::Strain( QObject* parent, QString type, QString id )
     setVal( 0 );  // start at 0 °C
 
     addPropGroup( { tr("Main"), {
-new DoubProp<Strain>( "Force_N"    , tr("Current Value"),"N", this, &Strain::getVal,  &Strain::setVal ),
-new DoubProp<Strain>( "Min_Force_N", tr("Minimum Value"),"N", this, &Strain::minVal,  &Strain::setMinVal ),
-new DoubProp<Strain>( "Max_Force_N", tr("Maximum Value"),"N", this, &Strain::maxVal,  &Strain::setMaxVal ),
-new DoubProp<Strain>( "Dial_Step"  , tr("Dial Step")    ,"N", this, &Strain::getStep, &Strain::setStep )
+        new DoubProp<Strain>("Force_N", tr("Current Value"), "N"
+                            , this, &Strain::getVal, &Strain::setVal ),
+
+        new DoubProp<Strain>("Min_Force_N", tr("Minimum Value"), "N"
+                            , this, &Strain::minVal,  &Strain::setMinVal ),
+
+        new DoubProp<Strain>("Max_Force_N", tr("Maximum Value"), "N"
+                            , this, &Strain::maxVal, &Strain::setMaxVal ),
+
+        new DoubProp<Strain>("Dial_Step", tr("Dial Step"), "N"
+                            , this, &Strain::getStep, &Strain::setStep )
     }, 0} );
     addPropGroup( { tr("Parameters"), {
-new DoubProp<Strain>( "Ref_Temp", tr("Ref. Temperature"),"ºC", this, &Strain::refTemp, &Strain::setRefTemp ),
-new DoubProp<Strain>( "Temp"    , tr("Temperature")     ,"ºC", this, &Strain::getTemp, &Strain::setTemp )
+        new DoubProp<Strain>("Ref_Temp", tr("Ref. Temperature"), "ºC"
+                            , this, &Strain::refTemp, &Strain::setRefTemp ),
+
+        new DoubProp<Strain>("Temp", tr("Temperature"), "ºC"
+                            , this, &Strain::getTemp, &Strain::setTemp )
     }, 0} );
     addPropGroup( { tr("Dial"), Dialed::dialProps(), groupNoCopy } );
 }
@@ -87,7 +99,7 @@ void Strain::updateStep()
     double res = sensorFunction( m_value );
     eResistor::setRes( res );
     if( m_propDialog ) m_propDialog->updtValues();
-    else if( m_showProperty == "Force_N" ) setValLabelText( getPropStr( "Force_N" ) );
+    else setValLabelText( getPropStr( showProp() ) );
 }
 
 void Strain::senseChanged( int val ) // Called when dial is rotated
@@ -139,4 +151,6 @@ void Strain::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget
         QPointF( 6, 0 ), };
 
     p->drawPolyline( points, 8 );
+
+    Component::paintSelected( p );
 }
