@@ -34,8 +34,11 @@ Thermistor::Thermistor( QString type, QString id )
     m_r25  = 10000;
 
     addPropGroup( { tr("Parameters"), {
-new IntProp<Thermistor>( "B"  , "B"  ,""  , this, &Thermistor::bVal, &Thermistor::setBval,0,"uint" ),
-new IntProp<Thermistor>( "R25", "R25","Ω" , this, &Thermistor::r25,  &Thermistor::setR25, 0,"uint" )
+        new IntProp<Thermistor>("B", "B",""
+                               , this, &Thermistor::bVal, &Thermistor::setBval,0,"uint" ),
+
+        new IntProp<Thermistor>("R25", "R25","Ω"
+                               , this, &Thermistor::r25, &Thermistor::setR25, 0,"uint" )
     }, 0} );
     addPropGroup( { tr("Dial"), Dialed::dialProps(), groupNoCopy } );
 }
@@ -55,7 +58,7 @@ void Thermistor::updateStep()
     double res = m_r25*qPow( e, m_bVal*k );
     eResistor::setRes( res );
     if( m_propDialog ) m_propDialog->updtValues();
-    else if( m_showProperty == "Temp" ) setValLabelText( getPropStr( "Temp" ) );
+    else setValLabelText( getPropStr( showProp() ) );
 }
 
 void Thermistor::setBval( int bval )
@@ -80,4 +83,6 @@ void Thermistor::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWi
     
     p->drawLine(-8, 6,  6,-8 );
     p->drawLine( 6,-8, 10,-8 );
+
+    Component::paintSelected( p );
 }
