@@ -11,21 +11,23 @@
 
 #include "doubleprop.h"
 
-Component* Resistor::construct( QObject* parent, QString type, QString id )
-{ return new Resistor( parent, type, id ); }
+#define tr(str) simulideTr("Resistor",str)
+
+Component* Resistor::construct( QString type, QString id )
+{ return new Resistor( type, id ); }
 
 LibraryItem* Resistor::libraryItem()
 {
     return new LibraryItem(
-        tr( "Resistor" ),
+        tr("Resistor"),
         "Resistors",
         "resistor.png",
         "Resistor",
         Resistor::construct);
 }
 
-Resistor::Resistor( QObject* parent, QString type, QString id )
-        : Comp2Pin( parent, type, id )
+Resistor::Resistor( QString type, QString id )
+        : Comp2Pin( type, id )
         , eResistor( id )
 {
     m_ePin[0] = m_pin[0];
@@ -35,16 +37,19 @@ Resistor::Resistor( QObject* parent, QString type, QString id )
     m_pin[1]->setLength( 5 );
 
     addPropGroup( { tr("Main"), {
-new DoubProp<Resistor>( "Resistance", tr("Resistance"), "Ω", this, &Resistor::getRes, &Resistor::setResSafe )
+        new DoubProp<Resistor>("Resistance", tr("Resistance"), "Ω"
+                              , this, &Resistor::getRes, &Resistor::setResSafe )
     }, 0 } );
 
     setShowProp("Resistance");
-    setPropStr( "Resistance", "100" );
+    setPropStr("Resistance", "100");
 }
 Resistor::~Resistor(){}
 
-void Resistor::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget )
+void Resistor::paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w )
 {
-    Component::paint( p, option, widget );
+    Component::paint( p, o, w );
     p->drawRect( m_area );
+
+    Component::paintSelected( p );
 }
