@@ -15,21 +15,23 @@
 #include "doubleprop.h"
 #include "boolprop.h"
 
-Component* FixedVolt::construct( QObject* parent, QString type, QString id )
-{ return new FixedVolt( parent, type, id ); }
+#define tr(str) simulideTr("FixedVolt",str)
+
+Component* FixedVolt::construct( QString type, QString id )
+{ return new FixedVolt( type, id ); }
 
 LibraryItem* FixedVolt::libraryItem()
 {
     return new LibraryItem(
-        tr( "Fixed Volt." ),
+        tr("Fixed Voltage"),
         "Sources",
         "voltage.png",
         "Fixed Voltage",
         FixedVolt::construct );
 }
 
-FixedVolt::FixedVolt( QObject* parent, QString type, QString id )
-          : Component( parent, type, id )
+FixedVolt::FixedVolt( QString type, QString id )
+          : Component( type, id )
           , eElement( id )
 {
     m_area = QRect( -10, -10, 20, 20 );
@@ -56,11 +58,11 @@ FixedVolt::FixedVolt( QObject* parent, QString type, QString id )
     
     Simulator::self()->addToUpdateList( this );
 
-    connect( m_button, &CustomButton::clicked,
-             this,     &FixedVolt::onbuttonclicked, Qt::UniqueConnection );
+    QObject::connect( m_button, &CustomButton::clicked, [=](){ onbuttonclicked(); } );
 
     addPropGroup( { tr("Main"), {
-new DoubProp<FixedVolt>( "Voltage", tr("Voltage"),"V", this, &FixedVolt::volt, &FixedVolt::setVolt )
+        new DoubProp<FixedVolt>("Voltage", tr("Voltage"), "V"
+                               , this, &FixedVolt::volt, &FixedVolt::setVolt )
     }, 0} );
 
     addPropGroup( { "Hidden", {
@@ -122,4 +124,6 @@ void FixedVolt::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWid
     else                        p->setBrush( QColor( 230, 230, 255 ) );
 
     p->drawRoundedRect( QRectF( -8, -8, 16, 16 ), 2, 2);
+
+    Component::paintSelected( p );
 }
