@@ -8,18 +8,17 @@
 
 #include "mech_contact.h"
 #include "inductor.h"
-//#include "e-resistor.h"
 
 class LibraryItem;
 class eNode;
 
-class MAINMODULE_EXPORT Relay : public MechContact
+class Relay : public MechContact
 {
     public:
-        Relay( QObject* parent, QString type, QString id );
+        Relay( QString type, QString id );
         ~Relay();
 
- static Component* construct( QObject* parent, QString type, QString id );
+ static Component* construct( QString type, QString id );
  static LibraryItem* libraryItem();
 
         double iTrig() { return m_trigCurrent; }
@@ -32,7 +31,7 @@ class MAINMODULE_EXPORT Relay : public MechContact
         virtual void stamp() override;
         virtual void voltChanged() override;
 
-        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget ) override;
+        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w ) override;
 
     protected:
         Inductor* m_inductor;
