@@ -52,7 +52,9 @@ class AppDialog : public QDialog, private Ui::AppDialog
         void on_reactStepBox_editingFinished();
 
         void on_slopeStepsBox_editingFinished();
-        void on_fastModeBox_toggled( bool fast );
+
+    private slots:
+        void on_fontName_currentFontChanged( const QFont &f );
 
     private:
         void updtHelp();
@@ -64,6 +66,7 @@ class AppDialog : public QDialog, private Ui::AppDialog
         bool m_showHelp;
 
         double m_speedP;
+        double m_scale;
 
         int      m_stepUnit;
         uint64_t m_stepsPS;
