@@ -18,7 +18,6 @@
 #include "utils.h"
 
 #include "stringprop.h"
-//#include "boolprop.h"
 
 Compiler::Compiler( CodeEditor* editor, OutPanelText* outPane )
         : QObject( editor )
@@ -28,7 +27,7 @@ Compiler::Compiler( CodeEditor* editor, OutPanelText* outPane )
     m_editor = editor;
     m_outPane = outPane;
 
-    m_file     = QDir::toNativeSeparators( editor->getFile() );
+    m_file     = editor->getFile();
     m_fileDir  = getFileDir( m_file );
     m_fileExt  = getFileExt( m_file );
     m_fileName = getBareName( m_file );
@@ -39,14 +38,18 @@ Compiler::Compiler( CodeEditor* editor, OutPanelText* outPane )
     clearCompiler();
 
     addPropGroup( { "Hidden", {
-new StrProp<Compiler>("itemtype"     ,"" ,"", this, &Compiler::itemType, &Compiler::setItemType ),
-new StrProp<Compiler>("compilertype" ,"" ,"", this, &Compiler::compName, &Compiler::setCompName ),
+        new StrProp<Compiler>("itemtype","" ,""
+                             , this, &Compiler::itemType, &Compiler::setItemType ),
+
+        new StrProp<Compiler>("compilertype","" ,""
+                             , this, &Compiler::compName, &Compiler::setCompName ),
     }, groupHidden} );
 
     addPropGroup( { tr("Compiler Settings"), {
-new ComProperty("", tr("For this compiler type:"),"","",0),
-new StrProp<Compiler> ("ToolPath", tr("Tool Path"),"", this
-                      , &Compiler::toolPath, &Compiler::setToolPath, 0,"path"),
+        new ComProperty("", tr("For this compiler type:"),"","",0),
+
+        new StrProp<Compiler>("ToolPath", tr("Tool Path"),""
+                             , this, &Compiler::toolPath, &Compiler::setToolPath, 0,"path"),
     }, 0} );
 }
 Compiler::~Compiler(){}
