@@ -5,6 +5,7 @@
 
 #include "avrpin.h"
 #include "mcuinterrupts.h"
+#include "datautils.h"
 
 AvrPin::AvrPin( McuPort* port, int i, QString id, Component* mcu )
       : McuPin( port, i, id, mcu )
@@ -20,7 +21,8 @@ void AvrPin::setPortState( bool state )
 
 void AvrPin::ConfExtInt( uint8_t bits )
 {
-    McuPin::ConfExtInt( bits );
+    if( !m_extInt ) return;
+    m_extIntTrigger = (extIntTrig_t)getRegBitsVal( bits, m_extIntBits );
     m_extInt->setContinuous( m_extIntTrigger == pinLow );
     voltChanged();
 }
